<?php
/**
 * Elementor Widget
 * @package ele blog
 * @since 1.0.0
 */

namespace Elementor;
class Eleblog_latest_Post_Slider_Widget extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'latest_news_slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return esc_html__( 'Latest News Slider', 'ele-blog' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'eicon-image-bold';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'ele-blog' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		/*
		* Display post
		*/
		$this->start_controls_section(
			'settings_display_post',
			[
				'label' => esc_html__( 'Display Post', 'ele-blog' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'section_title', [
				'label'   => esc_html__( 'Section Titlte', 'ele-blog' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Latest News', 'ele-blog' )
			]
		);

		$this->add_control(
			'ppr', [
				'label'   => esc_html__( 'Amount of item to display', 'ele-blog' ),
				'type'    => Controls_Manager::TEXT,
				'default' => 6
			]
		);

		$this->add_control(
			'orderby', [
				'label'   => esc_html__( 'Order by', 'ele-blog' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'author' => esc_html__( 'Author', 'ele-blog' ),
					'title'  => esc_html__( 'Title', 'ele-blog' ),
					'date'   => esc_html__( 'Date', 'ele-blog' ),
					'rand'   => esc_html__( 'Random', 'ele-blog' ),
				),
				'default' => 'date'

			]
		);

		$this->add_control(
			'order', [
				'label'   => esc_html__( 'Order', 'ele-blog' ),
				'type'    => Controls_Manager::SELECT2,
				'options' => array(
					'DESC' => esc_html__( 'DESC', 'ele-blog' ),
					'ASC'  => esc_html__( 'ASC', 'ele-blog' ),
				),
				'default' => 'DESC'

			]
		);

		$this->add_control(
			'select_cat', [
				'label'    => esc_html__( 'Select Category', 'ele-blog' ),
				'type'     => Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => ele_blog_post_category(),

			]
		);


		$this->add_control(
			'exclude_cat', [
				'label'    => esc_html__( 'Exclude Category', 'ele-blog' ),
				'type'     => Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => ele_blog_post_category(),
			]
		);

		$this->add_control(
			'select_tag', [
				'label'    => esc_html__( 'Select tag', 'ele-blog' ),
				'type'     => Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => ele_blog_post_tag(),
			]
		);

		$this->end_controls_section();

		//style
		$this->start_controls_section(
			'style',
			[
				'label' => esc_html__( 'Style', 'ele-blog' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		//section Title color
		$this->add_control(
			'section_title_color',
			[
				'label'     => esc_html__( 'Section Title Color', 'ele-blog' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#201654',
				'selectors' => [
					'{{WRAPPER}} .section-title .title' => 'color: {{VALUE}};',
				],
			]
		);

		//section typography
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'           => 'Section_title_typography',
				'label'          => esc_html__( 'Section Title Typography', 'ele-blog' ),
				'selector'       => '{{WRAPPER}} .section-title .title',
				'fields_options' => [
					// first mimic the click on Typography edit icon
					'typography'  => [ 'default' => 'yes' ],
					// then redifine the Elementor defaults
					'font_size'   => [ 'default' => [ 'size' => 20 ] ],
					'font_weight' => [ 'default' => 500 ],
					'line_height' => [ 'default' => [ 'size' => 27 ] ],
				],
			]
		);


		// Title color
		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'ele-blog' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#201654',
				'selectors' => [
					'{{WRAPPER}} .single-post-list-wrap .media h6.title a' => 'color: {{VALUE}};',
				],
			]
		);

		// Title color
		$this->add_control(
			'title_hover_color',
			[
				'label'     => esc_html__( 'Title Hover Color', 'ele-blog' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#2979ff',
				'selectors' => [
					'{{WRAPPER}} .single-post-list-wrap .media h6.title a:hover' => 'color: {{VALUE}};',
				],
			]
		);


		//title typography
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'           => 'title_typography',
				'label'          => esc_html__( 'Title Typography', 'ele-blog' ),
				'selector'       => '{{WRAPPER}} .media-body h6',
				'fields_options' => [
					// first mimic the click on Typography edit icon
					'typography'  => [ 'default' => 'yes' ],
					// then redifine the Elementor defaults
					'font_size'   => [ 'default' => [ 'size' => 18 ] ],
					'font_weight' => [ 'default' => 500 ],
					'line_height' => [ 'default' => [ 'size' => 24 ] ],
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<?php if ( ! empty( $settings['section_title'] ) ) : ?>
            <div class="section-title">
                <h6 class="title">Latest News</h6>
            </div>
		<?php endif; ?>

        <div class="post-slider owl-carousel ele-blog-latest-news-slider">
			<?php
			$ppr_first_column  = floor( $settings['ppr'] / 2 );
			$ppr_second_column = floor( $settings['ppr'] - $ppr_first_column );

			$ids[] = '';

			//for first column
			$args            = array(
				'post_type'           => 'post',
				'post_status'         => 'publish',
				'ignore_sticky_posts' => 1,
				'posts_per_page'      => $ppr_first_column,
			);
			$args['orderby'] = $settings['orderby'];
			$args['order']   = $settings['order'];

			if ( ! empty( $settings['exclude_cat'] ) ) {
				$args['category__not_in'][] = array_values( $settings['exclude_cat'] );
			}

			if ( ! empty( $settings['select_cat'] ) ) {
				$catgory             = implode( ', ', $settings['select_cat'] );
				$args['tax_query'][] = array(
					'taxonomy' => 'category',
					'field'    => 'id',
					'terms'    => array_values( $settings['select_cat'] )
				);
			}

			if ( ! empty( $settings['select_tag'] ) ) {
				$args['tax_query'][] = array(
					'taxonomy' => 'post_tag',
					'field'    => 'id',
					'terms'    => array_values( $settings['select_tag'] )
				);
			}


			//for second column

			$args2 = array(
				'post_type'           => 'post',
				'post_status'         => 'publish',
				'ignore_sticky_posts' => 1,
				'posts_per_page'      => $ppr_second_column,
			);

			$args2['orderby'] = $settings['orderby'];
			$args2['order']   = $settings['order'];

			if ( ! empty( $settings['exclude_cat'] ) ) {
				$args2['category__not_in'][] = array_values( $settings['exclude_cat'] );
			}

			if ( ! empty( $settings['select_cat'] ) ) {
				$args2['tax_query'][] = array(
					'taxonomy' => 'category',
					'field'    => 'id',
					'terms'    => array_values( $settings['select_cat'] )
				);
			}

			if ( ! empty( $settings['select_tag'] ) ) {
				$args2['tax_query'][] = array(
					'taxonomy' => 'post_tag',
					'field'    => 'id',
					'terms'    => array_values( $settings['select_tag'] )
				);
			}


			?>

            <div class="item">
				<?php
				$posts_query_first_column = new \WP_Query( $args );
				if ( $posts_query_first_column->have_posts() ):
					while ( $posts_query_first_column->have_posts() ): $posts_query_first_column->the_post();
						$ids[] = get_the_ID();
						$src = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full', false, '' );

						$img_id    = get_post_thumbnail_id( get_the_ID() );
						$image_alt = get_post_meta( $img_id, '_wp_attachment_image_alt', true );
						?>
                        <div class="single-post-list-wrap">
                            <div class="media">
								<?php if ( has_post_thumbnail() ) : ?>
                                    <div class="media-left">
									  <img src="<?php echo esc_url( ele_blog_img_resize( $src[0], 80, 80, true ) ); ?>">
                                    </div>
								<?php endif; ?>
                                <div class="media-body align-self-center">
                                    <div class="details">
                                        <div class="post-meta-single ele-post-meta-single">
                                            <ul>
                                                <li><?php eleblog_post_date(); ?></li>
                                            </ul>
                                        </div>
                                        <h6 class="title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h6>
                                    </div>
                                </div>
                            </div>
                        </div>
					<?php endwhile;
					wp_reset_postdata(); endif; ?>

            </div>

            <div class="item">
				<?php
				if ( ! empty( $ids ) ) {
					$args2['post__not_in'] = $ids;
				}
				$posts_query_second_column = new \WP_Query( $args2 );
				if ( $posts_query_second_column->have_posts() ):
					while ( $posts_query_second_column->have_posts() ): $posts_query_second_column->the_post();
						$src = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full', false, '' );

						$img_id    = get_post_thumbnail_id( get_the_ID() );
						$image_alt = get_post_meta( $img_id, '_wp_attachment_image_alt', true );
						?>
                        <div class="single-post-list-wrap">
                            <div class="media">
								<?php if ( has_post_thumbnail() ) : ?>
                                    <div class="media-left">
										 <img src="<?php echo esc_url( ele_blog_img_resize( $src[0], 80, 80, true ) ); ?>">
                                    </div>
								<?php endif; ?>
                                <div class="media-body">
                                    <div class="details">
                                        <div class="post-meta-single ele-post-meta-single">
                                            <ul>
                                                <li><?php eleblog_post_date(); ?></li>
                                            </ul>
                                        </div>
                                        <h6 class="title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h6>
                                    </div>
                                </div>
                            </div>
                        </div>
					<?php endwhile;
					wp_reset_postdata(); endif; ?>
            </div>
        </div>

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Eleblog_latest_Post_Slider_Widget() );